@@ -1,12 +1,9 @@
 from typing import List
 
-from instagrapi.exceptions import ClientError, ClientLoginRequired
-from instagrapi.extractors import (
-    extract_hashtag_gql,
-    extract_hashtag_v1,
-    extract_media_gql,
-    extract_media_v1,
-)
+from instagrapi.exceptions import (ClientError, ClientLoginRequired,
+                                   HashtagNotFound)
+from instagrapi.extractors import (extract_hashtag_gql, extract_hashtag_v1,
+                                   extract_media_gql, extract_media_v1)
 from instagrapi.types import Hashtag, Media
 from instagrapi.utils import dumps
 
@@ -34,12 +31,14 @@ class HashtagMixin:
             An object of Hashtag
         """
         params = {"max_id": max_id} if max_id else None
-        data = self.public_a1_request(
-            f"/explore/tags/{name}/", params=params
-        )
+        data = self.public_a1_request(f"/explore/tags/{name}/", params=params)
+        if not data.get("hashtag"):
+            raise HashtagNotFound(name=name, **data)
         return extract_hashtag_gql(data["hashtag"])
 
-    def hashtag_info_gql(self, name: str, amount: int = 12, end_cursor: str = None) -> Hashtag:
+    def hashtag_info_gql(
+        self, name: str, amount: int = 12, end_cursor: str = None
+    ) -> Hashtag:
         """
         Get information about a hashtag
 
@@ -59,16 +58,14 @@ class HashtagMixin:
         Hashtag
             An object of Hashtag
         """
-        variables = {
-            "tag_name": name,
-            "show_ranked": False,
-            "first": int(amount)
-        }
+        variables = {"tag_name": name, "show_ranked": False, "first": int(amount)}
         if end_cursor:
             variables["after"] = end_cursor
         data = self.public_graphql_request(
             variables, query_hash="f92f56d47dc7a55b606908374b43a314"
         )
+        if not data.get("hashtag"):
+            raise HashtagNotFound(name=name, **data)
         return extract_hashtag_gql(data["hashtag"])
 
     def hashtag_info_v1(self, name: str) -> Hashtag:
@@ -85,7 +82,7 @@ class HashtagMixin:
         Hashtag
             An object of Hashtag
         """
-        result = self.private_request(f'tags/{name}/info/')
+        result = self.private_request(f"tags/{name}/info/")
         return extract_hashtag_v1(result)
 
     def hashtag_info(self, name: str) -> Hashtag:
@@ -125,12 +122,16 @@ class HashtagMixin:
             List of objects of Hashtag
         """
         data = self.public_a1_request(f"/explore/tags/{name}/")
+        if not data.get("hashtag"):
+            raise HashtagNotFound(name=name, **data)
         return [
             extract_hashtag_gql(item["node"])
-            for item in data['hashtag']['edge_hashtag_to_related_tags']["edges"]
+            for item in data["hashtag"]["edge_hashtag_to_related_tags"]["edges"]
         ]
 
-    def hashtag_medias_a1(self, name: str, amount: int = 27, tab_key: str = '') -> List[Media]:
+    def hashtag_medias_a1(
+        self, name: str, amount: int = 27, tab_key: str = ""
+    ) -> List[Media]:
         """
         Get medias for a hashtag
 
@@ -153,9 +154,9 @@ class HashtagMixin:
         end_cursor = None
         while True:
             data = self.public_a1_request(
-                f'/explore/tags/{name}/',
-                params={"max_id": end_cursor} if end_cursor else {}
-            )['hashtag']
+                f"/explore/tags/{name}/",
+                params={"max_id": end_cursor} if end_cursor else {},
+            )["hashtag"]
             page_info = data["edge_hashtag_to_media"]["page_info"]
             end_cursor = page_info["end_cursor"]
             edges = data[tab_key]["edges"]
@@ -163,25 +164,36 @@ class HashtagMixin:
                 if amount and len(medias) >= amount:
                     break
                 # check uniq
-                media_pk = edge['node']['id']
+                media_pk = edge["node"]["id"]
                 if media_pk in unique_set:
                     continue
                 unique_set.add(media_pk)
                 # check contains hashtag in caption
-                media = extract_media_gql(edge['node'])
-                if f'#{name}' not in media.caption_text:
+                media = extract_media_gql(edge["node"])
+                if f"#{name}" not in media.caption_text:
                     continue
-                # fetch full media with User, Usertags, video_url
+                # Enrich media: Full user, usertags and video_url
                 medias.append(self.media_info_gql(media_pk))
-            if not page_info["has_next_page"] or not end_cursor:
-                break
-            if amount and len(medias) >= amount:
-                break
+            ######################################################
+            # infinity loop in hashtag_medias_top_a1
+            # https://github.com/adw0rd/instagrapi/issues/52
+            ######################################################
+            # Mikhail Andreev, [30.12.20 02:17]:
+            # Instagram always returns the same 9 medias for top
+            # I think we should return them without a loop
+            ######################################################
+            # if not page_info["has_next_page"] or not end_cursor:
+            #     break
+            # if amount and len(medias) >= amount:
+            #     break
+            break
         if amount:
             medias = medias[:amount]
         return medias
 
-    def hashtag_medias_v1(self, name: str, amount: int = 27, tab_key: str = '') -> List[Media]:
+    def hashtag_medias_v1(
+        self, name: str, amount: int = 27, tab_key: str = ""
+    ) -> List[Media]:
         """
         Get medias for a hashtag
 
@@ -200,29 +212,29 @@ class HashtagMixin:
             List of objects of Media
         """
         data = {
-            'supported_tabs': dumps([tab_key]),
+            "supported_tabs": dumps([tab_key]),
             # 'lat': 59.8626416,
             # 'lng': 30.5126682,
-            'include_persistent': 'true',
-            'rank_token': self.rank_token,
+            "include_persistent": "true",
+            "rank_token": self.rank_token,
         }
         max_id = None
         medias = []
         while True:
             result = self.private_request(
-                f'tags/{name}/sections/',
+                f"tags/{name}/sections/",
                 params={"max_id": max_id} if max_id else {},
-                data=self.with_default_data(data)
+                data=self.with_default_data(data),
             )
-            for section in result['sections']:
-                layout_content = section.get('layout_content') or {}
-                nodes = layout_content.get('medias') or []
+            for section in result["sections"]:
+                layout_content = section.get("layout_content") or {}
+                nodes = layout_content.get("medias") or []
                 for node in nodes:
                     if amount and len(medias) >= amount:
                         break
-                    media = extract_media_v1(node['media'])
+                    media = extract_media_v1(node["media"])
                     # check contains hashtag in caption
-                    if f'#{name}' not in media.caption_text:
+                    if f"#{name}" not in media.caption_text:
                         continue
                     medias.append(media)
             if not result["more_available"]:
@@ -250,10 +262,7 @@ class HashtagMixin:
         List[Media]
             List of objects of Media
         """
-        return self.hashtag_medias_a1(
-            name, amount,
-            tab_key='edge_hashtag_to_top_posts'
-        )
+        return self.hashtag_medias_a1(name, amount, tab_key="edge_hashtag_to_top_posts")
 
     def hashtag_medias_top_v1(self, name: str, amount: int = 9) -> List[Media]:
         """
@@ -271,7 +280,7 @@ class HashtagMixin:
         List[Media]
             List of objects of Media
         """
-        return self.hashtag_medias_v1(name, amount, tab_key='top')
+        return self.hashtag_medias_v1(name, amount, tab_key="top")
 
     def hashtag_medias_top(self, name: str, amount: int = 9) -> List[Media]:
         """
@@ -318,10 +327,7 @@ class HashtagMixin:
         List[Media]
             List of objects of Media
         """
-        return self.hashtag_medias_a1(
-            name, amount,
-            tab_key='edge_hashtag_to_media'
-        )
+        return self.hashtag_medias_a1(name, amount, tab_key="edge_hashtag_to_media")
 
     def hashtag_medias_recent_v1(self, name: str, amount: int = 27) -> List[Media]:
         """
@@ -339,7 +345,7 @@ class HashtagMixin:
         List[Media]
             List of objects of Media
         """
-        return self.hashtag_medias_v1(name, amount, tab_key='recent')
+        return self.hashtag_medias_v1(name, amount, tab_key="recent")
 
     def hashtag_medias_recent(self, name: str, amount: int = 27) -> List[Media]:
         """
