@@ -21,7 +21,7 @@ class User(BaseModel):
     media_count: int
     follower_count: int
     following_count: int
-    biography: Optional[str] = ''
+    biography: Optional[str] = ""
     external_url: Optional[HttpUrl]
     is_business: bool
 
@@ -33,7 +33,7 @@ class Account(BaseModel):
     is_private: bool
     profile_pic_url: HttpUrl
     is_verified: bool
-    biography: Optional[str] = ''
+    biography: Optional[str] = ""
     external_url: Optional[HttpUrl]
     is_business: bool
     birthday: Optional[str]
@@ -45,7 +45,7 @@ class Account(BaseModel):
 class UserShort(BaseModel):
     pk: int
     username: Optional[str]
-    full_name: Optional[str] = ''
+    full_name: Optional[str] = ""
     profile_pic_url: Optional[HttpUrl]
     # is_private: bool
     # is_verified: bool
@@ -60,7 +60,7 @@ class Usertag(BaseModel):
 class Location(BaseModel):
     pk: Optional[int]
     name: str
-    address: Optional[str] = ''
+    address: Optional[str] = ""
     lng: Optional[float]
     lat: Optional[float]
     external_id: Optional[int]
@@ -76,7 +76,7 @@ class Media(BaseModel):
     code: str
     taken_at: datetime
     media_type: int
-    product_type: Optional[str] = ''  # igtv or feed
+    product_type: Optional[str] = ""  # igtv or feed
     thumbnail_url: Optional[HttpUrl]
     location: Optional[Location] = None
     user: UserShort
@@ -88,7 +88,7 @@ class Media(BaseModel):
     video_url: Optional[HttpUrl]  # for Video and IGTV
     view_count: Optional[int] = 0  # for Video and IGTV
     video_duration: Optional[float] = 0.0  # for Video and IGTV
-    title: Optional[str] = ''
+    title: Optional[str] = ""
     resources: List[Resource] = []
 
 
@@ -151,7 +151,7 @@ class Story(BaseModel):
     code: str
     taken_at: datetime
     media_type: int
-    product_type: Optional[str] = ''
+    product_type: Optional[str] = ""
     thumbnail_url: Optional[HttpUrl]
     user: UserShort
     video_url: Optional[HttpUrl]  # for Video and IGTV
@@ -211,9 +211,9 @@ class DirectThread(BaseModel):
         :param user_id: You account user_id
         """
         user_id = str(user_id)
-        own_timestamp = int(self.last_seen_at[user_id]['timestamp'])
+        own_timestamp = int(self.last_seen_at[user_id]["timestamp"])
         timestamps = [
-            (int(v['timestamp']) - own_timestamp) > 0
+            (int(v["timestamp"]) - own_timestamp) > 0
             for k, v in self.last_seen_at.items()
             if k != user_id
         ]
